@@ -1,7 +1,7 @@
 package Perl::Examples::Accessors::Array;
 
-our $DATE = '2016-06-26'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-09-09'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 sub new {
     my ($class, %attrs) = @_;
@@ -10,12 +10,20 @@ sub new {
     $self;
 }
 
-sub attr1 {
+sub attr1_unoptimized {
     my $self = shift;
     $self->[0] = $_[0] if @_;
     $self->[0];
 }
 
+sub attr1 {
+    if (@_ > 1) {
+        $_[0][0] = $_[1];
+    } else {
+        $_[0][0];
+    }
+}
+
 1;
 # ABSTRACT:
 
@@ -31,13 +39,15 @@ Perl::Examples::Accessors::Array
 
 =head1 VERSION
 
-This document describes version 0.06 of Perl::Examples::Accessors::Array (from Perl distribution Perl-Examples-Accessors), released on 2016-06-26.
+This document describes version 0.07 of Perl::Examples::Accessors::Array (from Perl distribution Perl-Examples-Accessors), released on 2016-09-09.
 
 =head1 DESCRIPTION
 
 This is an example of a class which does not use any kind of object system or
 accessor generator. It is array-based.
 
+=for Pod::Coverage ^(attr1_unoptimized)$
+
 =head1 ATTRIBUTES
 
 =head2 attr1
