@@ -1,19 +1,27 @@
 package Perl::Examples::Accessors::Hash;
 
-our $DATE = '2016-06-26'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-09-09'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 sub new {
     my ($class, %attrs) = @_;
     bless \%attrs, $class;
 }
 
-sub attr1 {
+sub attr1_unoptimized {
     my $self = shift;
     $self->{attr1} = $_[0] if @_;
     $self->{attr1};
 }
 
+sub attr1 {
+    if (@_ > 1) {
+        $_[0]{attr1} = $_[1];
+    } else {
+        $_[0]{attr1};
+    }
+}
+
 1;
 # ABSTRACT:
 
@@ -29,13 +37,15 @@ Perl::Examples::Accessors::Hash
 
 =head1 VERSION
 
-This document describes version 0.06 of Perl::Examples::Accessors::Hash (from Perl distribution Perl-Examples-Accessors), released on 2016-06-26.
+This document describes version 0.07 of Perl::Examples::Accessors::Hash (from Perl distribution Perl-Examples-Accessors), released on 2016-09-09.
 
 =head1 DESCRIPTION
 
 This is an example of a class which does not use any kind of object system or
 accessor generator. It is hash-based.
 
+=for Pod::Coverage ^(attr1_unoptimized)$
+
 =head1 ATTRIBUTES
 
 =head2 attr1
